<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Regular_Blog
 */

get_header();

if ( is_front_page() && is_home() ) {
	require get_template_directory() . '/home.php';
} elseif ( is_front_page() && ! is_home() ) {
	?>
	<main id="primary" class="site-main">
		<?php
		require get_template_directory() . '/sections/sections.php';

		$homepage_sections = array( 'banner', 'about', 'trending-topics', 'projects', 'gallery', 'featured-video', 'blog', 'newsletter' );

		foreach ( $homepage_sections as $value ) {
			if ( in_array( $value, array( 'banner', 'about', 'trending-topics', 'projects', 'featured-video' ) ) ) {
				require get_theme_file_path() . '/inc/sections/' . $value . '.php';
			} else {
				require get_template_directory() . '/sections/' . $value . '.php';
			}
		}
		?>
	</main><!-- #main -->
	<?php
}

if ( true === get_theme_mod( 'enterpriseup_enable_frontpage_content', false ) ) {
	?>
	<div id="content" class="site-content ascendoor-wrapper">
		<div class="ascendoor-page">
			<main id="primary" class="site-main">
				<?php
				while ( have_posts() ) :
					the_post();

					get_template_part( 'template-parts/content', 'page' );

					// If comments are open or we have at least one comment, load up the comment template.
					if ( comments_open() || get_comments_number() ) :
						comments_template();
					endif;

				endwhile; // End of the loop.
				?>
				<div class="hello hi"></div>
			</main><!-- #main -->
		</div>
	</div>
	<?php
}

get_footer();
