<?php
/**
 * Regular Blog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Regular_Blog
 */

add_theme_support( 'title-tag' );

add_theme_support( 'automatic-feed-links' );

if ( ! function_exists( 'regular_blog_setup' ) ) :
	function regular_blog_setup() {
		/*
		* Make child theme available for translation.
		* Translations can be filed in the /languages/ directory.
		*/
		load_child_theme_textdomain( 'regular-blog', get_stylesheet_directory() . '/languages' );
	}
endif;
add_action( 'after_setup_theme', 'regular_blog_setup' );

if ( ! function_exists( 'regular_blog_enqueue_styles' ) ) :
	/**
	 * Enqueue scripts and styles.
	 */
	function regular_blog_enqueue_styles() {
		$parenthandle = 'enterpriseup-style';
		$theme        = wp_get_theme();

		// Append .min if SCRIPT_DEBUG is false.
		$min = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

		wp_enqueue_style( 'regular-blog-magnific-popup-css', get_theme_file_uri() . '/assets/css/magnific-popup.css', array(), '1.1.0' );

		wp_enqueue_style(
			$parenthandle,
			get_template_directory_uri() . '/style.css',
			array(
				'enterpriseup-slick-style',
				'enterpriseup-fontawesome-style',
				'enterpriseup-google-fonts',
			),
			$theme->parent()->get( 'Version' )
		);

		wp_enqueue_style(
			'regular-blog-style',
			get_stylesheet_uri(),
			array( $parenthandle ),
			$theme->get( 'Version' )
		);

		wp_enqueue_script( 'regular-blog-magnific-popup-js', get_theme_file_uri() . '/assets/js/jquery.magnific-popup' . $min . '.js', array( 'jquery' ), '1.1.0', true );

		wp_enqueue_script( 'regular-blog-script', get_stylesheet_directory_uri() . '/assets/js/custom.js', array( 'jquery', 'enterpriseup-custom-script' ), $theme->get( 'Version' ), true );

	}

endif;

add_action( 'wp_enqueue_scripts', 'regular_blog_enqueue_styles' );

require get_theme_file_path() . '/inc/customizer.php';

/**
 * Add section link on customizer preview.
 */
function regular_blog_section_link( $section_id ) {
	$section_name      = str_replace( 'regular_blog_', ' ', $section_id );
	$section_name      = str_replace( '_', ' ', $section_name );
	$starting_notation = '#';
	?>
	<span class="section-link">
		<span class="section-link-title"><?php echo esc_html( $section_name ); ?></span>
	</span>
	<style type="text/css">
		<?php echo $starting_notation . $section_id; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>:hover .section-link {
			visibility: visible;
		}
	</style>
	<?php
}
