<?php
/**
 * Featured Video Section
 *
 * @package Regular_Blog
 */

$wp_customize->add_section(
	'regular_blog_featured_video_section',
	array(
		'panel'    => 'enterpriseup_front_page_options',
		'title'    => esc_html__( 'Featured Video Section', 'regular-blog' ),
		'priority' => 55,
	)
);

// Featured Video Section - Enable Section.
$wp_customize->add_setting(
	'regular_blog_enable_featured_video_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'regular_blog_enable_featured_video_section',
		array(
			'label'    => esc_html__( 'Enable Featured Video Section', 'regular-blog' ),
			'section'  => 'regular_blog_featured_video_section',
			'settings' => 'regular_blog_enable_featured_video_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'regular_blog_enable_featured_video_section',
		array(
			'selector' => '#regular_blog_featured_video_section .section-link',
			'settings' => 'regular_blog_enable_featured_video_section',
		)
	);
}

// Featured Video Section - Section Subtitle.
$wp_customize->add_setting(
	'regular_blog_featured_video_subtitle',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_featured_video_subtitle',
	array(
		'label'           => esc_html__( 'Section Subtitle', 'regular-blog' ),
		'section'         => 'regular_blog_featured_video_section',
		'settings'        => 'regular_blog_featured_video_subtitle',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_featured_video_section_enabled',
	)
);

// Featured Video Section - Section Title.
$wp_customize->add_setting(
	'regular_blog_featured_video_title',
	array(
		'default'           => __( 'Watch the Video', 'regular-blog' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_featured_video_title',
	array(
		'label'           => esc_html__( 'Section Title', 'regular-blog' ),
		'section'         => 'regular_blog_featured_video_section',
		'settings'        => 'regular_blog_featured_video_title',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_featured_video_section_enabled',
	)
);

// Featured Video Section - Section Short Description.
$wp_customize->add_setting(
	'regular_blog_featured_video_short_description',
	array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_featured_video_short_description',
	array(
		'label'           => esc_html__( 'Section Short Description', 'regular-blog' ),
		'section'         => 'regular_blog_featured_video_section',
		'settings'        => 'regular_blog_featured_video_short_description',
		'type'            => 'textarea',
		'active_callback' => 'regular_blog_is_featured_video_section_enabled',
	)
);

// Featured Video Section - Background Image.
$wp_customize->add_setting(
	'regular_blog_featured_video_background_image',
	array(
		'sanitize_callback' => 'enterpriseup_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'regular_blog_featured_video_background_image',
		array(
			'label'           => esc_html__( 'Background Image', 'regular-blog' ),
			'section'         => 'regular_blog_featured_video_section',
			'settings'        => 'regular_blog_featured_video_background_image',
			'active_callback' => 'regular_blog_is_featured_video_section_enabled',
		)
	)
);

// Featured Video Section - Video Link.
$wp_customize->add_setting(
	'regular_blog_featured_video_video_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'regular_blog_featured_video_video_link',
	array(
		'label'           => esc_html__( 'Video Link', 'regular-blog' ),
		'section'         => 'regular_blog_featured_video_section',
		'settings'        => 'regular_blog_featured_video_video_link',
		'type'            => 'url',
		'active_callback' => 'regular_blog_is_featured_video_section_enabled',
	)
);
