<?php
/**
 * Projects Section
 *
 * @package EnterpriseUp
 */

$wp_customize->add_section(
	'regular_blog_projects_section',
	array(
		'panel'    => 'enterpriseup_front_page_options',
		'title'    => esc_html__( 'Projects Section', 'regular-blog' ),
		'priority' => 35,
	)
);

// Projects Section - Enable Section.
$wp_customize->add_setting(
	'regular_blog_enable_projects_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'regular_blog_enable_projects_section',
		array(
			'label'    => esc_html__( 'Enable Projects Section', 'regular-blog' ),
			'section'  => 'regular_blog_projects_section',
			'settings' => 'regular_blog_enable_projects_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'regular_blog_enable_projects_section',
		array(
			'selector' => '#regular_blog_projects_section .section-link',
			'settings' => 'regular_blog_enable_projects_section',
		)
	);
}

// Projects Section - Section Title.
$wp_customize->add_setting(
	'regular_blog_projects_title',
	array(
		'default'           => __( 'Latest Projects', 'regular-blog' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_title',
	array(
		'label'           => esc_html__( 'Section Title', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_title',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
	)
);

// Projects Section - Section Text.
$wp_customize->add_setting(
	'regular_blog_projects_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_text',
	array(
		'label'           => esc_html__( 'Section Text', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_text',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
	)
);

// Projects Section - Button Label.
$wp_customize->add_setting(
	'regular_blog_projects_button_label',
	array(
		'default'           => __( 'View All', 'regular-blog' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_button_label',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
	)
);

// Banner Section - Button Link.
$wp_customize->add_setting(
	'regular_blog_projects_button_link',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_button_link',
	array(
		'label'           => esc_html__( 'Button Link ', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_button_link',
		'type'            => 'url',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
	)
);

// Projects Section - Content Type.
$wp_customize->add_setting(
	'regular_blog_projects_content_type',
	array(
		'default'           => 'page',
		'sanitize_callback' => 'enterpriseup_sanitize_select',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_content_type',
	array(
		'label'           => esc_html__( 'Select Content Type', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_content_type',
		'type'            => 'select',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
		'choices'         => array(
			'page' => esc_html__( 'Page', 'regular-blog' ),
			'post' => esc_html__( 'Post', 'regular-blog' ),
		),
	)
);

for ( $i = 1; $i <= 4; $i++ ) {
	// Projects Section - Select Post.
	$wp_customize->add_setting(
		'regular_blog_projects_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'regular_blog_projects_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'regular-blog' ) . $i,
			'section'         => 'regular_blog_projects_section',
			'settings'        => 'regular_blog_projects_content_post_' . $i,
			'active_callback' => 'regular_blog_is_projects_section_and_content_type_post_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_choices(),
		)
	);

	// Projects Section - Select Page.
	$wp_customize->add_setting(
		'regular_blog_projects_content_page_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'regular_blog_projects_content_page_' . $i,
		array(
			'label'           => esc_html__( 'Select Page ', 'regular-blog' ) . $i,
			'section'         => 'regular_blog_projects_section',
			'settings'        => 'regular_blog_projects_content_page_' . $i,
			'active_callback' => 'regular_blog_is_projects_section_and_content_type_page_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_page_choices(),
		)
	);

}

// Projects Section - Read More Text.
$wp_customize->add_setting(
	'regular_blog_projects_read_more_text',
	array(
		'default'           => __( 'Learn More', 'regular-blog' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'regular_blog_projects_read_more_text',
	array(
		'label'           => esc_html__( 'Read More Text', 'regular-blog' ),
		'section'         => 'regular_blog_projects_section',
		'settings'        => 'regular_blog_projects_read_more_text',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_projects_section_enabled',
	)
);
