<?php
/**
 * Trending Topics Section
 *
 * @package Regular_Blog
 */

$wp_customize->add_section(
	'regular_blog_trending_topics_section',
	array(
		'panel'    => 'enterpriseup_front_page_options',
		'title'    => esc_html__( 'Trending Topics Section', 'regular-blog' ),
		'priority' => 32,
	)
);

// Trending Topics Section - Enable Section.
$wp_customize->add_setting(
	'regular_blog_enable_trending_topics_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'enterpriseup_sanitize_switch',
	)
);

$wp_customize->add_control(
	new EnterpriseUp_Toggle_Switch_Custom_Control(
		$wp_customize,
		'regular_blog_enable_trending_topics_section',
		array(
			'label'    => esc_html__( 'Enable Trending Topics Section', 'regular-blog' ),
			'section'  => 'regular_blog_trending_topics_section',
			'settings' => 'regular_blog_enable_trending_topics_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'regular_blog_enable_trending_topics_section',
		array(
			'selector' => '#regular_blog_trending_topics_section .section-link',
			'settings' => 'regular_blog_enable_trending_topics_section',
		)
	);
}

// Trending Topics Section - Section Title.
$wp_customize->add_setting(
	'regular_blog_trending_topics_title',
	array(
		'default'           => __( 'Trending Topics', 'regular-blog' ),
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_trending_topics_title',
	array(
		'label'           => esc_html__( 'Section Title', 'regular-blog' ),
		'section'         => 'regular_blog_trending_topics_section',
		'settings'        => 'regular_blog_trending_topics_title',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
	)
);

// Trending Topics Section - Section Text.
$wp_customize->add_setting(
	'regular_blog_trending_topics_text',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_trending_topics_text',
	array(
		'label'           => esc_html__( 'Section Text', 'regular-blog' ),
		'section'         => 'regular_blog_trending_topics_section',
		'settings'        => 'regular_blog_trending_topics_text',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
	)
);

for ( $i = 1; $i <= 4; $i++ ) {

	// Trending Topics Section - Select Category.
	$wp_customize->add_setting(
		'regular_blog_trending_topics_content_category_' . $i,
		array(
			'sanitize_callback' => 'enterpriseup_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'regular_blog_trending_topics_content_category_' . $i,
		array(
			'label'           => esc_html__( 'Select Category ', 'regular-blog' ) . $i,
			'section'         => 'regular_blog_trending_topics_section',
			'settings'        => 'regular_blog_trending_topics_content_category_' . $i,
			'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
			'type'            => 'select',
			'choices'         => enterpriseup_get_post_cat_choices(),
		)
	);

	// Trending Topics Section - Category Image.
	$wp_customize->add_setting(
		'regular_blog_trending_topics_category_image_' . $i,
		array(
			'sanitize_callback' => 'enterpriseup_sanitize_image',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'regular_blog_trending_topics_category_image_' . $i,
			array(
				'label'           => esc_html__( 'Category Image ', 'regular-blog' ) . $i,
				'section'         => 'regular_blog_trending_topics_section',
				'settings'        => 'regular_blog_trending_topics_category_image_' . $i,
				'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
			)
		)
	);
}

// Trending Topics Section - Button Label.
$wp_customize->add_setting(
	'regular_blog_trending_topics_button_label',
	array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field',
		'transport'         => 'postMessage',
	)
);

$wp_customize->add_control(
	'regular_blog_trending_topics_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'regular-blog' ),
		'section'         => 'regular_blog_trending_topics_section',
		'settings'        => 'regular_blog_trending_topics_button_label',
		'type'            => 'text',
		'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
	)
);

// Trending Topics Section - Button Link.
$wp_customize->add_setting(
	'regular_blog_trending_topics_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'regular_blog_trending_topics_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'regular-blog' ),
		'section'         => 'regular_blog_trending_topics_section',
		'settings'        => 'regular_blog_trending_topics_button_link',
		'type'            => 'url',
		'active_callback' => 'regular_blog_is_trending_topics_section_enabled',
	)
);
