<?php

if ( ! get_theme_mod( 'regular_blog_enable_projects_section', false ) ) {
	return;
}

$content_ids  = array();
$content_type = get_theme_mod( 'regular_blog_projects_content_type', 'page' );

for ( $i = 1; $i <= 4; $i++ ) {
	$content_ids[] = get_theme_mod( 'regular_blog_projects_content_' . $content_type . '_' . $i );
}

$args = array(
	'post_type'           => $content_type,
	'post__in'            => $content_ids,
	'orderby'             => 'post__in',
	'posts_per_page'      => absint( 4 ),
	'ignore_sticky_posts' => true,
);

$args = apply_filters( 'regular_blog_projects_section_args', $args );

regular_blog_render_projects_section( $args );

/**
 * Render Projects Section.
 */
function regular_blog_render_projects_section( $args ) {
	$section_title  = get_theme_mod( 'regular_blog_projects_title', __( 'Latest Projects', 'regular-blog' ) );
	$section_text   = get_theme_mod( 'regular_blog_projects_text' );
	$button_label   = get_theme_mod( 'regular_blog_projects_button_label', __( 'View All', 'regular-blog' ) );
	$button_link    = get_theme_mod( 'regular_blog_projects_button_link' );
	$button_link    = ! empty( $button_link ) ? $button_link : '#';
	$read_more_text = get_theme_mod( 'regular_blog_projects_read_more_text', __( 'Learn More', 'regular-blog' ) );
	?>
	<section id="regular_blog_projects_section" class="enterpriseup-frontpage-section enterpriseup-background enterpriseup-prom-section enterpriseup-three-col-prom-section">
		<?php
		if ( is_customize_preview() ) :
			regular_blog_section_link( 'regular_blog_projects_section' );
		endif;
		?>
		<div class="ascendoor-wrapper">
			<div class="section-header-subtitle section-header-subtitle-left">
				<?php if ( ! empty( $section_title || $section_text ) ) : ?>
					<div class="section-header-subtitle-wrapper">
						<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
						<p class="section-subtitle"><?php echo esc_html( $section_text ); ?></p>
					</div>
				<?php endif; ?>
				<?php if ( ! empty( $button_label ) ) : ?>
					<div class="enterpriseup-latest-news-view-all enterpriseup-button">
						<a href="<?php echo esc_url( $button_link ); ?>"><?php echo esc_html( $button_label ); ?></a>
					</div>
				<?php endif; ?>
			</div>
			<?php
			$query = new WP_Query( $args );
			if ( $query->have_posts() ) :
				?>
				<div class="enterpriseup-section-body">
					<div class="enterpriseup-prom-section-wrapper">
						<?php
						while ( $query->have_posts() ) :
							$query->the_post();
							?>
							<div class="enterpriseup-prom-single">
								<div class="enterpriseup-prom-img">
									<?php the_post_thumbnail( 'full' ); ?>
								</div>
								<div class="enterpriseup-prom-detail">
									<h4 class="enterpriseup-prom-subtitle"><?php echo wp_kses_post( wp_trim_words( get_the_content(), 10 ) ); ?></h4>
									<h3 class="enterpriseup-prom-title"><?php the_title(); ?></h3>
									<div class="enterpriseup-button enterpriseup-button-noborder-alternate">
										<a href="<?php the_permalink(); ?>"><?php echo esc_html( $read_more_text ); ?></a>
									</div>
								</div>
							</div>
							<?php
						endwhile;
						wp_reset_postdata();
						?>
					</div>    
				</div>    
				<?php
			endif;
			?>
		</div>
	</section>
	<?php
}
