<?php
if ( ! get_theme_mod( 'regular_blog_enable_trending_topics_section', false ) ) {
	return;
}
$content_ids = array();

for ( $i = 1; $i <= 4; $i++ ) {
	$content_ids[] = get_theme_mod( 'regular_blog_trending_topics_content_category_' . $i );
}

$args = array(
	'taxonomy'   => 'category',
	'include'    => (array) $content_ids,
	'orderby'    => 'include',
	'order'      => 'asc',
	'hide_empty' => false,
	'number'     => absint( 4 ),
);

$args = apply_filters( 'regular_blog_trending_topics_section_args', $args );

regular_blog_render_trending_topics_section( $args );

/**
 * Render Trending Topics Section.
 */
function regular_blog_render_trending_topics_section( $args ) {
	$section_title = get_theme_mod( 'regular_blog_trending_topics_title', __( 'Trending Topics', 'regular-blog' ) );
	$section_text  = get_theme_mod( 'regular_blog_trending_topics_text' );
	$button_label  = get_theme_mod( 'regular_blog_trending_topics_button_label' );
	$button_link   = get_theme_mod( 'regular_blog_trending_topics_button_link' );
	$button_link   = ! empty( $button_link ) ? $button_link : '#';

	$terms = get_terms( $args );

	?>
	<section id="regular_blog_trending_topics_section" class="enterpriseup-frontpage-section enterpriseup-background enterpriseup-trending-section">
		<?php
		if ( is_customize_preview() ) :
			regular_blog_section_link( 'regular_blog_trending_topics_section' );
		endif;
		?>
		<div class="ascendoor-wrapper">
			<div class="section-header-subtitle section-header-subtitle-left">
				<?php if ( ! empty( $section_title || $section_text ) ) { ?>
					<div class="section-header-subtitle-wrapper">
						<h3 class="section-title"><?php echo esc_html( $section_title ); ?></h3>
						<p class="section-subtitle"><?php echo esc_html( $section_text ); ?></p>
					</div>
				<?php } ?>
				<?php if ( ! empty( $button_label ) ) { ?>
					<div class="enterpriseup-latest-news-view-all enterpriseup-button">
						<a href="<?php echo esc_url( $button_link ); ?>"><?php echo esc_html( $button_label ); ?></a>
					</div>
				<?php } ?>
			</div>
			<?php if ( ( isset( $terms ) && ! empty( $terms ) && ! is_wp_error( $terms ) ) ) { ?>
				<div class="enterpriseup-section-body">
					<div class="enterpriseup-trending-section-wrapper">
						<?php
						$i = 1;
						foreach ( $terms as $value ) {
							$term_link = get_term_link( $value, 'category' );
							$cat_image = get_theme_mod( 'regular_blog_trending_topics_category_image_' . $i );
							?>
							<div class="trending-single">
								<a href="<?php echo esc_url( $term_link ); ?>" class="trending_item_img-wrapper">
									<?php if ( ! empty( $cat_image ) ) { ?>
									<img src="<?php echo esc_url( $cat_image ); ?>" class="trending_item_img" alt="<?php echo esc_attr( $value->name ); ?>">
									<?php } ?>
									<h5 class="trending_item_title"><?php echo esc_html( $value->name ); ?></h5>
								</a>
							</div>
							<?php
							$i++;
						}
						?>
					</div>
				</div>
			<?php } ?>
		</div>
	</section>
	<?php
}
